import { Observable } from 'rxjs';
import { Document } from './document.js';
import '../common/position.js';

interface DocumentCreated<T extends Document> {
    document: T;
}
interface DocumentClosed {
    uri: string;
}
interface DocumentOpened<T extends Document> {
    document: T;
}
interface DocumentDeleted {
    uri: string;
}
interface DocumentChanged<T extends Document> {
    document: T;
}
interface DocumentAccessor<T extends Document = Document> {
    readonly created$: Observable<DocumentCreated<T>>;
    readonly closed$: Observable<DocumentClosed>;
    readonly opened$: Observable<DocumentOpened<T>>;
    readonly deleted$: Observable<DocumentDeleted>;
    readonly changed$: Observable<DocumentChanged<T>>;
    get(uri: string): Promise<T | undefined>;
    all(): Promise<T[]>;
    active(): Promise<T[]>;
}

export type { DocumentAccessor, DocumentChanged, DocumentClosed, DocumentCreated, DocumentDeleted, DocumentOpened };
