import { Observable } from 'rxjs';
import { Document } from './document.cjs';
import { DocumentAccessor, DocumentCreated, DocumentClosed, DocumentOpened, DocumentDeleted, DocumentChanged } from './document-accessor.cjs';
import { DocumentFactory } from './document-factory.cjs';
import { DocumentReader } from './document-reader.cjs';
import { TextDocumentChange } from './text-document-change.cjs';
import '../common/position.cjs';
import '../common/range.cjs';

declare class DocumentManager<TDoc extends Document = Document, TChange = TextDocumentChange, TContent = string> implements DocumentAccessor<TDoc> {
    private readonly factory;
    private readonly reader?;
    private readonly documents;
    private readonly activeDocuments;
    private readonly createdSubject;
    private readonly closedSubject;
    private readonly openedSubject;
    private readonly deletedSubject;
    private readonly changedSubject;
    constructor(factory: DocumentFactory<TDoc, TChange, TContent>, reader?: DocumentReader<TContent> | undefined);
    get created$(): Observable<DocumentCreated<TDoc>>;
    get closed$(): Observable<DocumentClosed>;
    get opened$(): Observable<DocumentOpened<TDoc>>;
    get deleted$(): Observable<DocumentDeleted>;
    get changed$(): Observable<DocumentChanged<TDoc>>;
    add(doc: TDoc): void;
    get(uri: string): Promise<TDoc | undefined>;
    all(): Promise<TDoc[]>;
    active(): Promise<TDoc[]>;
    fireCreated(uri: string): Promise<void>;
    fireClosed(uri: string): Promise<void>;
    fireOpened(uri: string, format: string, version: number, content: TContent): Promise<void>;
    fireDeleted(uri: string): Promise<void>;
    fireChanged(uri: string, changes?: readonly TChange[], version?: number): Promise<void>;
    private reload;
}

export { DocumentManager };
