import { findScriptureNodes } from './scripture-document.js';
class ScriptureContainer {
  constructor(children, range = { start: { line: 0, character: 0 }, end: { line: 0, character: 0 } }) {
    this.range = range;
    this._children = [];
    this.isLeaf = false;
    if (children != null) {
      for (const child of children) {
        this.appendChild(child);
      }
    }
  }
  get document() {
    return this._parent?.document;
  }
  get parent() {
    return this._parent;
  }
  get children() {
    return this._children;
  }
  updateParent(parent) {
    this._parent = parent;
  }
  remove() {
    if (this._parent == null) {
      throw new Error("The node does not have a parent.");
    }
    this._parent.removeChild(this);
  }
  getText() {
    if (this.document == null) {
      throw new Error("The node is not part of a document.");
    }
    return this.document.getText(this.range);
  }
  findNodes(filter) {
    return findScriptureNodes(this, filter);
  }
  positionAt(offset) {
    if (this.document == null) {
      throw new Error("The node is not part of a document.");
    }
    return this.document.positionAt(offset, this.range);
  }
  appendChild(child) {
    this._children.push(child);
    child.updateParent(this);
  }
  insertChild(index, child) {
    this._children.splice(index, 0, child);
    child.updateParent(this);
  }
  removeChild(child) {
    if (child.parent !== this) {
      throw new Error("This node does not contain the specified child.");
    }
    const index = this._children.indexOf(child);
    if (index === -1) {
      throw new Error("This node does not contain the specified child.");
    }
    this._children.splice(index, 1);
    child.updateParent(void 0);
  }
  spliceChildren(start, deleteCount, ...items) {
    const removed = this._children.splice(start, deleteCount, ...items);
    for (const child of removed) {
      child.updateParent(void 0);
    }
    for (const child of items) {
      child.updateParent(this);
    }
  }
  clearChildren() {
    this._children.length = 0;
  }
}
export {
  ScriptureContainer
};
