import { findScriptureNodes, ScriptureNodeType } from './scripture-document.js';
import { TextDocument } from './text-document.js';
class ScriptureTextDocument extends TextDocument {
  constructor(uri, format, version, content, children) {
    super(uri, format, version, content);
    this._children = [];
    this.type = ScriptureNodeType.Document;
    this.document = this;
    this.parent = void 0;
    this.isLeaf = false;
    this.range = { start: { line: 0, character: 0 }, end: { line: 0, character: 0 } };
    if (children != null) {
      for (const child of children) {
        this.appendChild(child);
      }
    }
  }
  get children() {
    return this._children;
  }
  updateParent(_parent) {
    throw new Error("The method is not supported.");
  }
  remove() {
    throw new Error("The method is not supported.");
  }
  findNodes(filter) {
    return findScriptureNodes(this, filter);
  }
  appendChild(child) {
    this._children.push(child);
    child.updateParent(this);
  }
  insertChild(index, child) {
    this._children.splice(index, 0, child);
    child.updateParent(this);
  }
  removeChild(child) {
    if (child.parent !== this) {
      throw new Error("This node does not contain the specified child.");
    }
    const index = this._children.indexOf(child);
    if (index === -1) {
      throw new Error("This node does not contain the specified child.");
    }
    this._children.splice(index, 1);
    child.updateParent(void 0);
  }
  spliceChildren(start, deleteCount, ...items) {
    const removed = this._children.splice(start, deleteCount, ...items);
    for (const child of removed) {
      child.updateParent(void 0);
    }
    for (const child of items) {
      child.updateParent(this);
    }
  }
  clearChildren() {
    this._children.length = 0;
  }
}
export {
  ScriptureTextDocument
};
