import i18next from "i18next";
class Localizer {
  constructor(language) {
    this.backend = new LocalBackend();
    this.i18n = i18next.createInstance({
      lng: language,
      fallbackLng: "en",
      partialBundledLanguages: true,
      ns: [],
      resources: {}
    }).use(this.backend);
  }
  get language() {
    return this.i18n.language;
  }
  async init() {
    await this.i18n.init();
    await this.i18n.loadNamespaces(Array.from(this.backend.namespaces));
  }
  addNamespace(namespace, loader) {
    if (this.i18n.hasLoadedNamespace(namespace)) {
      return;
    }
    this.backend.addNamespace(namespace, loader);
  }
  async changeLanguage(language) {
    await this.i18n.changeLanguage(language);
  }
  t(key, options) {
    return this.i18n.t(key, options);
  }
}
class LocalBackend {
  constructor() {
    this.namespaceLoaders = /* @__PURE__ */ new Map();
    this.type = "backend";
  }
  get namespaces() {
    return this.namespaceLoaders.keys();
  }
  init(_services, _backendOptions, _i18nextOptions) {
  }
  addNamespace(namespace, loader) {
    this.namespaceLoaders.set(namespace, loader);
  }
  read(language, namespace, callback) {
    const loader = this.namespaceLoaders.get(namespace);
    if (loader == null) {
      callback(new Error(`No loader for namespace ${namespace}`));
      return;
    }
    Promise.resolve(loader(language)).then((data) => {
      if (data != null && typeof data === "object" && "default" in data) {
        data = data.default;
      }
      callback(null, data);
    }).catch(callback);
  }
}
export {
  Localizer
};
