"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var workspace_exports = {};
__export(workspace_exports, {
  Workspace: () => Workspace
});
module.exports = __toCommonJS(workspace_exports);
var import_rxjs = require("rxjs");
class Workspace {
  constructor(config) {
    this.lastDiagnosticChangedEvents = /* @__PURE__ */ new Map();
    this.localizer = config.localizer;
    this.diagnosticProviders = new Map(config.diagnosticProviders?.map((provider) => [provider.id, provider]));
    this.diagnosticsChanged$ = (0, import_rxjs.merge)(
      ...Array.from(this.diagnosticProviders.values()).map(
        (provider, i) => provider.diagnosticsChanged$.pipe(
          (0, import_rxjs.tap)((e) => {
            this.updateCombinedDiagnosticChangedEvent(i, e);
          })
        )
      )
    ).pipe((0, import_rxjs.map)((e) => this.getCombinedDiagnosticChangedEvent(e.uri, e.version)));
    this.onTypeFormattingProviders = new Map(
      config.onTypeFormattingProviders?.map((provider) => [provider.id, provider])
    );
  }
  async init() {
    await Promise.all(Array.from(this.diagnosticProviders.values()).map((provider) => provider.init()));
    await Promise.all(Array.from(this.onTypeFormattingProviders.values()).map((provider) => provider.init()));
    await this.localizer.init();
  }
  changeLanguage(language) {
    return this.localizer.changeLanguage(language);
  }
  async getDiagnostics(uri) {
    const diagnostics = [];
    for (const provider of this.diagnosticProviders.values()) {
      diagnostics.push(...await provider.getDiagnostics(uri));
    }
    return diagnostics;
  }
  async getDiagnosticFixes(uri, diagnostic) {
    const provider = this.diagnosticProviders.get(diagnostic.source);
    if (provider == null) {
      return [];
    }
    return await provider.getDiagnosticFixes(uri, diagnostic);
  }
  getOnTypeTriggerCharacters() {
    const characters = /* @__PURE__ */ new Set();
    for (const provider of this.onTypeFormattingProviders.values()) {
      for (const ch of provider.onTypeTriggerCharacters) {
        characters.add(ch);
      }
    }
    return Array.from(characters);
  }
  async getOnTypeEdits(uri, position, ch) {
    for (const provider of this.onTypeFormattingProviders.values()) {
      if (provider.onTypeTriggerCharacters.has(ch)) {
        const edits = await provider.getOnTypeEdits(uri, position, ch);
        if (edits != null) {
          return edits;
        }
      }
    }
    return void 0;
  }
  updateCombinedDiagnosticChangedEvent(providerIndex, event) {
    const docEvents = this.lastDiagnosticChangedEvents.get(event.uri) ?? [];
    docEvents[providerIndex] = event;
    this.lastDiagnosticChangedEvents.set(event.uri, docEvents);
  }
  getCombinedDiagnosticChangedEvent(uri, version) {
    const docEvents = this.lastDiagnosticChangedEvents.get(uri) ?? [];
    const diagnostics = [];
    for (const docEvent of docEvents) {
      if (version == null || docEvent.version === version) {
        diagnostics.push(...docEvent.diagnostics);
      }
    }
    return {
      uri,
      version,
      diagnostics
    };
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  Workspace
});
