import { Localizer } from './localizer.js';
import { Observable } from 'rxjs';
import { Position } from '../common/position.js';
import { TextEdit } from '../common/text-edit.js';
import { Diagnostic } from '../diagnostic/diagnostic.js';
import { DiagnosticFix } from '../diagnostic/diagnostic-fix.js';
import { DiagnosticProvider, DiagnosticsChanged } from '../diagnostic/diagnostic-provider.js';
import { OnTypeFormattingProvider } from '../formatting/on-type-formatting-provider.js';
import '../common/range.js';

interface WorkspaceConfig<T = TextEdit> {
    localizer: Localizer;
    diagnosticProviders?: DiagnosticProvider<T>[];
    onTypeFormattingProviders?: OnTypeFormattingProvider<T>[];
}
declare class Workspace<T = TextEdit> {
    private readonly localizer;
    private readonly diagnosticProviders;
    private readonly onTypeFormattingProviders;
    private readonly lastDiagnosticChangedEvents;
    readonly diagnosticsChanged$: Observable<DiagnosticsChanged>;
    constructor(config: WorkspaceConfig<T>);
    init(): Promise<void>;
    changeLanguage(language: string): Promise<void>;
    getDiagnostics(uri: string): Promise<Diagnostic[]>;
    getDiagnosticFixes(uri: string, diagnostic: Diagnostic): Promise<DiagnosticFix<T>[]>;
    getOnTypeTriggerCharacters(): string[];
    getOnTypeEdits(uri: string, position: Position, ch: string): Promise<T[] | undefined>;
    private updateCombinedDiagnosticChangedEvent;
    private getCombinedDiagnosticChangedEvent;
}

export { Workspace, type WorkspaceConfig };
